package javax.net.ssl;

import java.io.IOException;
import java.security.KeyManagementException;
import java.security.SecureRandom;

public abstract class SSLContextSpi
{
    public SSLContextSpi() {
    }
    
    protected abstract void engineInit(KeyManager[] p0, TrustManager[] p1, SecureRandom p2) throws KeyManagementException;
    
    protected abstract SSLSocketFactory engineGetSocketFactory();
    
    protected abstract SSLServerSocketFactory engineGetServerSocketFactory();
    
    protected abstract SSLEngine engineCreateSSLEngine();
    
    protected abstract SSLEngine engineCreateSSLEngine(String p0, int p1);
    
    protected abstract SSLSessionContext engineGetServerSessionContext();
    
    protected abstract SSLSessionContext engineGetClientSessionContext();
    
    private SSLSocket getDefaultSocket() {
        try {
            return (SSLSocket)this.engineGetSocketFactory().createSocket();
        }
        catch (IOException cause) {
            throw new UnsupportedOperationException("Could not obtain parameters", cause);
        }
    }
    
    protected SSLParameters engineGetDefaultSSLParameters() {
        return this.getDefaultSocket().getSSLParameters();
    }
    
    protected SSLParameters engineGetSupportedSSLParameters() {
        SSLSocket defaultSocket = this.getDefaultSocket();
        SSLParameters sslParameters = new SSLParameters();
        sslParameters.setCipherSuites(defaultSocket.getSupportedCipherSuites());
        sslParameters.setProtocols(defaultSocket.getSupportedProtocols());
        return sslParameters;
    }
}
